abacusai.agent_data_upload_result — AbacusAI documentation

# `abacusai.agent_data_upload_result`

## Module Contents

### Classes

`AgentDataUploadResult` | Results of uploading data to agent.

class abacusai.agent_data_upload_result.AgentDataUploadResult(client, docInfos={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Results of uploading data to agent.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docInfos (AgentDataDocumentInfo) – A list of dict for information on the documents uploaded to agent.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict